@@ -433,7 +433,7 @@ sub get_config_files ($)
 	# get first match...
         my ($offset, $tmp) = @{$tmp[0]};
 	# and remove possibly enclosing square brackets
-	($tmp) = split "\s*,\s*", $tmp;
+	($tmp) = split /\s*,\s*/, $tmp;
 	if ($tmp =~ m/\s*\[ ( [^\]]+ ) \]/x) {
 	    $tmp = $1;
 	    $offset += $-[1];
@@ -601,9 +601,18 @@ sub output_am_file
     open NEWFILE, "> $new_file" || 
 	return &report_error (3, "Can't open $new_file for writing");;
 
-    foreach (@{$makefile->{lines}}) {
-	chomp;
-	print NEWFILE $_, "\n";
+    my $last_line = scalar (@{$makefile->{lines}});
+    my $current_line = 1;
+    foreach my $line (@{$makefile->{lines}}) {
+	chomp $line;
+	
+	## last line is empty, do not output a newline together with it.
+	if (($current_line == $last_line) && $line eq "") {
+	    print NEWFILE $line;
+	} else {
+	    print NEWFILE $line, "\n";
+	}
+	$current_line++;
     }
     close NEWFILE;
     return 0;
@@ -825,8 +834,12 @@ sub analyze_macro_style
 	} elsif ($bs_column != 0 && $bs != $bs_column) {
 	    # bs column changed, get amount of separation
 	    chomp $line_copy;
-	    $line_copy =~ s/.+[^ ](\s+)\z/$1/;
-	    $bs_column = - length ($line_copy);
+	    if ($line_copy =~ s/.+[^ ](\s+)\z/$1/) {
+		$bs_column = - length ($line_copy);
+	    } else {
+		## Line has zero spacing. So use 1 instead.
+		$bs_column = -1;
+	    };
 	};
 	
 	$first_line = 0;
@@ -1416,7 +1429,8 @@ sub format_line ($$$)
 
     $start_column = 0 if !defined $start_column;
     my $expanded_line = expand_tabs $line;
-    my $item_count = split /\s+/, trim (chop_backslash $line);
+    my @line_items = split /\s+/, trim (chop_backslash $line);
+    my $item_count = scalar @line_items;
     my $width = $style->{width} > 0 ? $style->{width} : $style->{max_width};
 
 #     print "Formatting $line";
